class Endpoints:
    def __init__(self, base_url="https://sandbox-api.paddle.com"):
        self._base_url = base_url

    def __getattribute__(self, name):
        print(name)
        value = super().__getattribute__(name)
        if name.startswith("_"):
            return value
        return f"{self._base_url}/{value.lstrip('/')}"

    # Products
    create_product: str = "products"
    get_product: str = "products/{product_id}"
    list_products: str = "products"
    update_product: str = "products/{product_id}"

    # Prices
    create_price: str = "prices"
    get_price: str = "prices/{price_id}"
    list_prices: str = "prices"
    update_price: str = "prices/{price_id}"

    # Discounts
    create_discount: str = "discounts"
    get_discount: str = "discounts/{discount_id}"
    list_discounts: str = "discounts"
    update_discount: str = "discounts/{discount_id}"

    # Customers
    create_customer: str = "customers"
    get_customer: str = "customers/{customer_id}"
    list_customers: str = "customers"
    update_customer: str = "customers/{customer_id}"

    # Addresses
    create_address_for_customer: str = "customers/{customer_id}/addresses"
    get_address_for_customer: str = "customers/{customer_id}/addresses/{address_id}"
    list_addresses_for_customer: str = "customers/{customer_id}/addresses"
    update_address_for_customer: str = "customers/{customer_id}/addresses/{address_id}"

    # Businesses
    create_business_for_customer: str = "customers/{customer_id}/businesses"
    get_business_for_customer: str = "customers/{customer_id}/businesses/{business_id}"
    list_businesses_for_customer: str = "customers/{customer_id}/businesses"
    update_business_for_customer: str = (
        "customers/{customer_id}/businesses/{business_id}"
    )

    # Transactions
    create_transaction: str = "transactions"
    get_transaction: str = "transactions/{transaction_id}"
    list_transactions: str = "transactions"
    update_transaction: str = "transactions/{transaction_id}"
    preview_transaction: str = "transactions/preview"
    get_pdf_for_transaction: str = "transactions/{transaction_id}/invoice"

    # Subscriptions
    get_subscription: str = "subscriptions/{subscription_id}"
    list_subscriptions: str = "subscriptions"
    preview_update_subscription: str = "subscriptions/{subscription_id}/preview"
    update_subscription: str = "subscriptions/{subscription_id}"
    get_transaction_to_update_payment_method: str = (
        "subscriptions/{subscription_id}/update-payment-method-transaction"
    )
    preview_one_time_charge: str = "subscriptions/{subscription_id}/charge/preview"
    create_one_time_charge: str = "subscriptions/{subscription_id}/charge"
    pause_subscription: str = "subscriptions/{subscription_id}/pause"
    resume_subscription: str = "subscriptions/{subscription_id}/resume"
    cancel_subscription: str = "subscriptions/{subscription_id}/cancel"

    # Adjustments
    create_adjustment: str = "adjustments"
    list_adjustments: str = "adjustments"

    # Pricing Preview
    preview_prices: str = "pricing-preview"

    # Events
    list_event_types: str = "event-types"
    list_events: str = "events"

    # Notification settings
    create_notification_setting: str = "notification-settings"
    get_notification_setting: str = "notification-settings/{notification_setting_id}"
    list_notification_settings: str = "notification-settings"
    update_notification_setting: str = "notification-settings/{notification_setting_id}"
    delete_notification_setting: str = "notification-settings/{notification_setting_id}"

    # Notifications
    get_notification: str = "notifications/{notification_id}"
    list_notifications: str = "notifications"
    replay_notification: str = "notifications/{notification_id}/replay"



from __future__ import annotations

from typing import List, Literal, Optional

from datetime import datetime

from pydantic import validator

from paddle_billing_client.models import LazyBaseModel as BaseModel
from paddle_billing_client.models import PaddleResponse


class AddressBase(BaseModel):
    description: str | None
    first_line: str | None
    second_line: str | None
    city: str | None
    postal_code: str | None
    region: str | None
    country_code: str | None
    status: Literal["active", "archived"] | None


class Address(AddressBase):
    id: str | None
    created_at: datetime | None
    updated_at: datetime | None


class AddressQueryParams(BaseModel):
    # Return entities after the specified cursor. Used for working through paginated results.
    after: str | None = None
    # Return only the IDs specified. Use a comma separated list to get multiple entities.
    id: str | None = None
    # Order returned entities by the specified field and direction ([ASC] or [DESC]).
    order_by: Literal["[ASC]", "[DESC]"] | None = None
    # Set how many entities are returned per page. Default: 50
    per_page: int | None = None
    # Return entities that match a search query. Searches id and type fields.
    search: str | None = None
    # Return entities that match the specified status. Use a comma separated list to specify multiple status values.
    status: str | None = None

    @validator("status", allow_reuse=True)
    def check_status(cls, v: str) -> str:  # pragma: no cover
        valid_statuses = ["active", "archived"]
        if not all([s in valid_statuses for s in v.split(",")]):
            raise ValueError(
                f"Query param invalid status: {v}, allowed values: {valid_statuses}"
            )
        return v


class AddressResponse(PaddleResponse):
    data: Address


class AddressesResponse(PaddleResponse):
    data: list[Address]


class AddressRequest(AddressBase):
    pass



from __future__ import annotations

from typing import List, Literal, Optional

from datetime import datetime

from pydantic import Field, root_validator, validator

from paddle_billing_client.models import LazyBaseModel as BaseModel
from paddle_billing_client.models import PaddleResponse
from paddle_billing_client.utils import parse_event_to_model


class NotificationIdPathParams(BaseModel):
    notificationId: str


class NotificationPayload(BaseModel):
    notification_id: str
    event_id: str
    event_type: str
    data: dict
    occurred_at: datetime

    @root_validator(pre=False, allow_reuse=True)
    def select_data(cls, values):  # pragma: no cover
        values["data"] = parse_event_to_model(values["event_type"], values["data"])
        return values


class Notification(BaseModel):
    id: str
    type: str
    status: str
    payload: NotificationPayload
    occurred_at: datetime
    delivered_at: datetime
    replayed_at: str | None
    origin: str
    last_attempt_at: datetime
    retry_at: str | None
    times_attempted: int
    notification_setting_id: str


class NotificationQueryParams(BaseModel):
    # Return entities after the specified cursor. Used for working through paginated results.
    after: str | None = None
    # Return entities related to the specified notification destination.
    # Use a comma separated list to specify multiple notification destination IDs.
    notification_setting_id: str | None = None
    # Order returned entities by the specified field and direction ([ASC] or [DESC]).
    order_by: Literal["[ASC]", "[DESC]"] | None = None
    # Set how many entities are returned per page. Default: 50
    per_page: int | None = None
    # Return entities that match a search query. Searches id and type fields.
    search: str | None = None
    # Return entities that match the specified status. Use a comma separated list to specify multiple status values.
    status: str | None = None
    # Return entities that contain the Paddle ID specified. Pass a transaction, customer, or subscription ID.
    filter: str | None = None
    # Return entities up to a specific time.
    to: str | None = None
    # Return entities from a specific time.
    from_field: str | None = Field(None, alias="from")

    @validator("status", allow_reuse=True)
    def check_status(cls, v: str) -> str:  # pragma: no cover
        valid_statuses = ["delivered", "failed", "needs_retry", "not_attempted"]
        if not all([s in valid_statuses for s in v.split(",")]):
            raise ValueError(
                f"Query param invalid status: {v}, allowed values: {valid_statuses}"
            )
        return v


class NotificationResponse(PaddleResponse):
    data: Notification


class NotificationsResponse(PaddleResponse):
    data: list[Notification]


class NotificationReplay(BaseModel):
    event_id: str | None


class NotificationReplayResponse(PaddleResponse):
    data: NotificationReplay



from typing import List, Literal, Optional

from datetime import datetime

from pydantic import validator

from paddle_billing_client.models import LazyBaseModel as BaseModel
from paddle_billing_client.models import PaddleResponse


class CustomerBase(BaseModel):
    email: str
    name: Optional[str]
    locale: Optional[str]


class Customer(CustomerBase):
    id: str
    marketing_consent: bool
    created_at: Optional[datetime]
    updated_at: Optional[datetime]
    imported_at: Optional[datetime]
    source: Optional[str]
    status: Optional[Literal["active", "archived"]]
    is_sanctioned: Optional[bool]
    tax_exemptions: Optional[List[str]]


class CustomerQueryParams(BaseModel):
    # Return entities after the specified cursor. Used for working through paginated results.
    after: Optional[str] = None
    # Return only the IDs specified. Use a comma separated list to get multiple entities.
    id: Optional[str] = None
    # Order returned entities by the specified field and direction ([ASC] or [DESC]).
    order_by: Optional[Literal["[ASC]", "[DESC]"]] = None
    # Set how many entities are returned per page. Default: 50
    per_page: Optional[int] = None
    # Return entities that match a search query. Searches id and type fields.
    search: Optional[str] = None
    # Return entities that match the specified status. Use a comma separated list to specify multiple status values.
    status: Optional[str] = None

    @validator("status", allow_reuse=True)
    def check_status(cls, v: str) -> str:  # pragma: no cover
        valid_statuses = ["active", "archived"]
        if not all([s in valid_statuses for s in v.split(",")]):
            raise ValueError(
                f"Query param invalid status: {v}, allowed values: {valid_statuses}"
            )
        return v


class CustomerResponse(PaddleResponse):
    data: Customer


class CustomersResponse(PaddleResponse):
    data: List[Customer]


class CustomerRequest(CustomerBase):
    pass



from typing import Dict, List, Literal, Optional

from pydantic import validator

from paddle_billing_client.models import LazyBaseModel as BaseModel
from paddle_billing_client.models import PaddleResponse


class UnitPrice(BaseModel):
    amount: str
    currency_code: str


class Quantity(BaseModel):
    minimum: int
    maximum: int


class BillingCycle(BaseModel):
    interval: str
    frequency: int


class UnitPriceOverride(BaseModel):
    country_codes: List[str]
    unit_price: UnitPrice


class PriceBase(BaseModel):
    description: str
    product_id: Optional[str]
    billing_cycle: Optional[BillingCycle]
    trial_period: Optional[str]
    tax_mode: str
    unit_price_overrides: Optional[List[UnitPriceOverride]]
    quantity: Optional[Quantity]
    custom_data: Optional[Dict[str, str]]


class Price(PriceBase):
    id: str
    unit_price: UnitPrice
    status: Optional[str]


class PriceQueryParams(BaseModel):
    # Return entities after the specified cursor. Used for working through paginated results.
    after: Optional[str] = None
    # Return only the IDs specified. Use a comma separated list to get multiple entities.
    id: Optional[str] = None
    # Include related entities in the response.
    include: Optional[Literal["product"]] = None
    # Order returned entities by the specified field and direction ([ASC] or [DESC]).
    order_by: Optional[Literal["[ASC]", "[DESC]"]] = None
    # Set how many entities are returned per page. Default: 50
    per_page: Optional[int] = None
    # Return entities that match the specified status. Use a comma separated list to specify multiple status values.
    status: Optional[str] = None
    # Determine whether returned entities are for recurring prices (true) or one-time prices (false).
    recurring: Optional[bool] = None

    @validator("status", allow_reuse=True)
    def check_status(cls, v: str) -> str:  # pragma: no cover
        valid_statuses = ["active", "archived"]
        if not all([s in valid_statuses for s in v.split(",")]):
            raise ValueError(
                f"Query param invalid status: {v}, allowed values: {valid_statuses}"
            )
        return v


class PriceResponse(PaddleResponse):
    data: Price


class PricesResponse(PaddleResponse):
    data: List[Price]


class PriceRequest(PriceBase):
    pass



from __future__ import annotations

from typing import Any, Dict, List, Literal, Optional

from datetime import datetime

from pydantic import validator
from pydantic.types import Enum

from paddle_billing_client.models.base import LazyBaseModel as BaseModel


class AdjustmentAction(str, Enum):
    refund = "refund"
    credit = "credit"
    chargeback = "chargeback"
    chargeback_warning = "chargeback_warning"


class AdjustmentStatus(str, Enum):
    pending_approval = "pending_approval"
    approved = "approved"
    rejected = "rejected"


class AdjustmentItem(BaseModel):
    id: str | None
    item_id: str
    type: str
    amount: str
    proration: str | None
    totals: dict | None


class AdjustmentBase(BaseModel):
    # How this adjustment impacts the related transaction.
    # 'refund' adjustments must be approved by Paddle, and are created with the status 'pending_approval'.
    # 'chargeback' and 'chargeback_warning' adjustments are created automatically by Paddle.
    action: AdjustmentAction
    transaction_id: str
    reason: str | None
    items: list[AdjustmentItem]


class Adjustment(AdjustmentBase):
    id: str
    subscription_id: str | None
    customer_id: str
    currency_code: str
    # Status of this adjustment. Set automatically by Paddle.
    # 'refund' adjustments must be approved by Paddle,
    # and are created with the status 'pending_approval' until they move to 'approved' or 'rejected' on review.
    # 'credit' adjustments are created with the status 'approved'.
    status: AdjustmentStatus
    totals: dict
    payout_totals: dict
    created_at: datetime
    updated_at: datetime


class AdjustmentQueryParams(BaseModel):
    # Return entities for the specified action.
    action: AdjustmentAction | None
    # Return entities after the specified cursor. Used for working through paginated results.
    after: str | None = None
    # Return entities related to the specified customer. Use a comma separated list to specify multiple customer IDs.
    customer_id: str | None
    # Order returned entities by the specified field and direction ([ASC] or [DESC]).
    order_by: Literal["[ASC]", "[DESC]"] | None = None
    # Set how many entities are returned per page. Default: 50
    per_page: int | None = None
    # Return entities that match the specified status. Use a comma separated list to specify multiple status values.
    status: str | None = None
    # Return entities related to the specified subscription.
    # Use a comma separated list to specify multiple subscription IDs.
    subscription_id: str | None
    # Return entities related to the specified transaction.
    # Use a comma separated list to specify multiple transaction IDs.
    transaction_id: str | None
    # Return only the IDs specified.
    # Use a comma separated list to get multiple entities.
    id: str | None = None

    @validator("status", allow_reuse=True)
    def check_status(cls, v: str) -> str:  # pragma: no cover
        valid_statuses = ["approved", "pending_approval", "rejected", "reversed"]
        if not all([s in valid_statuses for s in v.split(",")]):
            raise ValueError(
                f"Query param invalid status: {v}, allowed values: {valid_statuses}"
            )
        return v


class AdjustmentResponse(BaseModel):
    data: Adjustment


class AdjustmentsResponse(BaseModel):
    data: list[Adjustment]


class AdjustmentRequest(AdjustmentBase):
    pass


if __name__ == "__main__":
    adjustment = Adjustment(
        id="1",
        action="refund",
        transaction_id="1",
        subscription_id="1",
        customer_id="1",
        reason="1",
        currency_code="USD",
        status="pending_approval",
        items=[],
        totals={},
        payout_totals={},
        created_at="2023-03-21T18:34:44.148562Z",
        updated_at="2023-03-21T18:34:44.148562Z",
    )
    print(adjustment.action == AdjustmentAction.refund)



from __future__ import annotations

from typing import List, Literal, Optional

from datetime import datetime

from pydantic import validator

from paddle_billing_client.models.base import LazyBaseModel as BaseModel
from paddle_billing_client.models.base import PaddleResponse
from paddle_billing_client.models.common import BillingPeriod
from paddle_billing_client.models.price import BillingCycle, Price
from paddle_billing_client.models.transaction import Transaction


class Item(BaseModel):
    price: Price | None
    price_id: str | None
    status: str | None
    quantity: int | None
    recurring: bool | None
    created_at: datetime | None
    updated_at: datetime | None
    next_billed_at: datetime | None
    previously_billed_at: datetime | None


class ScheduledChange(BaseModel):
    action: Literal["cancel", "pause", "resume"] | None
    effective_at: datetime | None
    resume_at: datetime | None


class SubscriptionBase(BaseModel):
    status: str | None
    customer_id: str | None
    address_id: str | None
    business_id: str | None
    currency_code: str | None
    created_at: datetime | None
    updated_at: datetime | None
    started_at: datetime | None
    first_billed_at: datetime | None
    next_billed_at: datetime | None
    paused_at: datetime | None
    canceled_at: datetime | None
    collection_mode: str | None
    billing_details: dict | None
    current_billing_period: BillingPeriod | None
    billing_cycle: BillingCycle | None
    recurring_transaction_details: dict | None
    scheduled_change: ScheduledChange | None
    items: list[Item] | None
    custom_data: dict | None
    management_urls: dict | None


class Subscription(SubscriptionBase):
    id: str | None
    next_transaction: Transaction | None
    immediate_transaction: Transaction | None


class SubscriptionQueryParams(BaseModel):
    # Return entities after the specified cursor. Used for working through paginated results.
    after: str | None = None
    # Return entities related to the specified customer.
    # Use a comma separated list to specify multiple customer IDs.
    customer_id: str | None = None
    # Order returned entities by the specified field and direction ([ASC] or [DESC]).
    order_by: Literal["[ASC]", "[DESC]"] | None = None
    # Set how many entities are returned per page. Default: 50
    per_page: int | None = None
    # Return entities related to the specified price. Use a comma separated list to specify multiple price IDs.
    price_id: str | None = None
    # Return entities that match the specified status. Use a comma separated list to specify multiple status values.
    status: str | None = None

    @validator("status", allow_reuse=True)
    def check_status(cls, v: str) -> str:  # pragma: no cover
        valid_statuses = ["active", "canceled", "past_due", "paused", "trialing"]
        if not all([s in valid_statuses for s in v.split(",")]):
            raise ValueError(
                f"Query param invalid status: {v}, allowed values: {valid_statuses}"
            )
        return v


class SubscriptionResponse(PaddleResponse):
    data: Subscription


class SubscriptionsResponse(PaddleResponse):
    data: list[Subscription]


class SubscriptionRequest(SubscriptionBase):
    effective_from: datetime | Literal["next_billing_period", "immediately"] | None
    resume_at: datetime | None



from typing import Optional

from pydantic import BaseModel


class LazyBaseModel(BaseModel):
    class Config:
        extra = "allow"


class Pagination(LazyBaseModel):
    per_page: int
    estimated_total: int
    next: Optional[str]
    has_more: bool


class Meta(LazyBaseModel):
    pagination: Optional[Pagination]
    request_id: str


class PaddleResponse(LazyBaseModel):
    meta: Meta



from __future__ import annotations

from typing import Dict, List, Literal, Optional

from datetime import datetime

from pydantic import validator

from paddle_billing_client.models import LazyBaseModel as BaseModel
from paddle_billing_client.models import PaddleResponse
from paddle_billing_client.models.address import Address
from paddle_billing_client.models.business import Business
from paddle_billing_client.models.common import BillingPeriod
from paddle_billing_client.models.customer import Customer
from paddle_billing_client.models.discount import Discount
from paddle_billing_client.models.product import Product


class TaxRatesTotals(BaseModel):
    subtotal: str
    discount: str
    tax: str
    total: str


class TaxRatesUsed(BaseModel):
    tax_rate: str
    totals: TaxRatesTotals


class Totals(BaseModel):
    subtotal: str
    discount: str
    tax: str
    total: str
    credit: str
    balance: str
    grand_total: str
    fee: str | None
    earnings: str | None
    currency_code: str


class AdjustedTotals(BaseModel):
    subtotal: str
    tax: str
    total: str
    grand_total: str
    fee: str | None
    earnings: str | None
    currency_code: str


class PayoutTotals(BaseModel):
    subtotal: str
    discount: str
    tax: str
    total: str
    credit: str
    balance: str
    grand_total: str
    fee: str
    earnings: str
    currency_code: str


class ChargebackFeeOriginal(BaseModel):
    amount: str
    currency_code: str


class ChargebackFee(BaseModel):
    amount: str
    original: ChargebackFeeOriginal | None


class AdjustedPayoutTotals(BaseModel):
    subtotal: str
    tax: str
    total: str
    fee: str
    chargeback_fee: ChargebackFee | None
    earnings: str
    currency_code: str


class LineItemProration(BaseModel):
    rate: str
    billing_period: BillingPeriod


class LineItemUnitTotals(BaseModel):
    subtotal: str
    discount: str
    tax: str
    total: str


class LineItemTotals(BaseModel):
    subtotal: str
    discount: str
    tax: str
    total: str


class LineItem(BaseModel):
    id: str | None
    price_id: str | None
    quantity: int
    proration: LineItemProration | None
    tax_rate: str
    unit_totals: LineItemUnitTotals
    totals: LineItemTotals
    product: Product


class TransactionDetails(BaseModel):
    tax_rates_used: list[TaxRatesUsed] | None
    totals: Totals | None
    adjusted_totals: AdjustedTotals | None
    payout_totals: PayoutTotals | None
    adjusted_payout_totals: AdjustedPayoutTotals | None
    line_items: list[LineItem] | None


class BillingDetails(BaseModel):
    enable_checkout: bool | None
    payment_terms: dict | None
    purchase_order_number: str | None
    additional_information: str | None


class TransactionBase(BaseModel):
    items: list[dict] | None
    status: None | (
        Literal["draft", "ready", "billed", "paid", "completed", "canceled", "past_due"]
    )
    customer_id: str | None
    address_id: str | None
    business_id: str | None
    discount_id: str | None
    custom_data: dict | None
    collection_mode: Literal["automatic", "manual"] | None
    billing_details: BillingDetails | None
    billing_period: BillingPeriod | None
    currency_code: str | None
    customer_ip_address: str | None
    ignore_trials: bool | None
    address: Address | None


class Transaction(TransactionBase):
    id: str | None
    customer: Customer | None
    business: Business | None
    discount: Discount | None
    seller: dict | None
    adjustments_totals: dict | None
    origin: str | None
    subscription_id: str | None
    invoice_id: str | None
    invoice_number: str | None
    created_at: datetime | None
    updated_at: datetime | None
    billed_at: str | None
    details: TransactionDetails
    payments: list[dict] | None
    checkout: dict | None


class TransactionPreview(TransactionBase):
    pass


class TransactionQueryParams(BaseModel):
    # Return entities after the specified cursor. Used for working through paginated results.
    after: str | None = None
    # Return entities billed at a specific time.
    # Pass an RFC 3339 datetime string,
    # or use [LT] (less than), [LTE] (less than or equal to),
    # [GT] (greater than), or [GTE] (greater than or equal to) operators.
    # For example, billed_at=2023-04-18T17:03:26 or billed_at[LT]=2023-04-18T17:03:26.
    billed_at: datetime | str | None = None
    collection_mode: Literal["automatic", "manual"] | None = None
    # Return entities created at a specific time.
    # Pass an RFC 3339 datetime string,
    # or use [LT] (less than), [LTE] (less than or equal to),
    # [GT] (greater than), or [GTE] (greater than or equal to) operators.
    # For example, billed_at=2023-04-18T17:03:26 or billed_at[LT]=2023-04-18T17:03:26.
    created_at: datetime | str | None = None
    # Return entities related to the specified customer. Use a comma separated list to specify multiple customer IDs.
    customer_id: str | None
    # Return only the IDs specified. Use a comma separated list to get multiple entities.
    id: str | None = None
    # Include related entities in the response.
    # address|business|customer|discount|seller|adjustment|adjustments_totals
    include: str | None = None
    invoice_number: str | None = None
    # Order returned entities by the specified field and direction ([ASC] or [DESC]).
    order_by: Literal["[ASC]", "[DESC]"] | None = None
    # Set how many entities are returned per page. Default: 50
    per_page: int | None = None
    # Return entities that match the specified status. Use a comma separated list to specify multiple status values.
    status: str | None = None
    # Return entities related to the specified subscription.
    # Use a comma separated list to specify multiple subscription IDs.
    subscription_id: str | None
    # Return entities updated at a specific time.
    # Pass an RFC 3339 datetime string,
    # or use [LT] (less than), [LTE] (less than or equal to),
    # [GT] (greater than), or [GTE] (greater than or equal to) operators.
    # For example, billed_at=2023-04-18T17:03:26 or billed_at[LT]=2023-04-18T17:03:26.
    updated_at: datetime | str | None = None

    @validator("status", allow_reuse=True)
    def check_status(cls, v: str) -> str:  # pragma: no cover
        valid_statuses = [
            "draft",
            "ready",
            "billed",
            "paid",
            "completed",
            "canceled",
            "past_due",
        ]
        if not all([s in valid_statuses for s in v.split(",")]):
            raise ValueError(
                f"Query param invalid status: {v}, allowed values: {valid_statuses}"
            )
        return v


class TransactionResponse(PaddleResponse):
    data: Transaction


class TransactionsResponse(PaddleResponse):
    data: list[Transaction]


class TransactionRequest(TransactionBase):
    pass


class TransactionPreviewResponse(PaddleResponse):
    data: TransactionPreview


class TransactionPdf(BaseModel):
    url: str


class TransactionPdfResponse(PaddleResponse):
    data: TransactionPdf



from __future__ import annotations

from typing import List, Literal, Optional

from datetime import datetime

from pydantic import root_validator

from paddle_billing_client.models import LazyBaseModel as BaseModel
from paddle_billing_client.models import PaddleResponse
from paddle_billing_client.utils import parse_event_to_model


class EventType(BaseModel):
    name: str
    description: str
    group: str
    available_versions: list[int]


class EventTypesResponse(PaddleResponse):
    data: list[EventType]


class EventQueryParams(BaseModel):
    # Return entities after the specified cursor. Used for working through paginated results.
    after: str | None = None
    # Order returned entities by the specified field and direction ([ASC] or [DESC]).
    order_by: Literal["[ASC]", "[DESC]"] | None = None
    # Set how many entities are returned per page. Default: 50
    per_page: int | None = None


class Event(BaseModel):
    notification_id: str | None
    event_id: str
    event_type: str
    data: dict
    occurred_at: datetime

    @root_validator(pre=False, allow_reuse=True)
    def select_data(cls, values):  # pragma: no cover
        values["data"] = parse_event_to_model(values["event_type"], values["data"])
        return values


class EventsResponse(PaddleResponse):
    data: list[Event]



from typing import List, Literal, Optional

from paddle_billing_client.models import LazyBaseModel as BaseModel


class SubscribedEvent(BaseModel):
    name: str
    description: str
    group: str
    available_versions: List[int]


class NotificationSettingBase(BaseModel):
    description: str
    destination: str
    subscribed_events: List[SubscribedEvent]
    type: Optional[Literal["email", "url"]]
    active: bool
    api_version: int
    include_sensitive_fields: bool


class NotificationSetting(NotificationSettingBase):
    id: str
    endpoint_secret_key: str


class NotificationSettingResponse(BaseModel):
    data: NotificationSetting


class NotificationSettingsResponse(BaseModel):
    data: List[NotificationSetting]


class NotificationSettingRequest(NotificationSettingBase):
    subscribed_events: List[str]
